@@ -17,6 +17,7 @@
 package org.apache.servicemix.jbi.deployer.impl;
 
 import java.io.File;
+import java.io.IOException;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.Dictionary;
@@ -33,7 +34,7 @@ import javax.management.MBeanServer;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.servicemix.jbi.deployer.Component;
-import org.apache.servicemix.jbi.deployer.DeployedAssembly;
+import org.apache.servicemix.common.osgi.DeployedAssembly;
 import org.apache.servicemix.jbi.deployer.ServiceAssembly;
 import org.apache.servicemix.jbi.deployer.SharedLibrary;
 import org.apache.servicemix.jbi.deployer.ServiceUnit;
@@ -53,6 +54,7 @@ import org.apache.servicemix.jbi.deployer.descriptor.ServiceAssemblyDesc;
 import org.apache.servicemix.jbi.deployer.descriptor.ServiceUnitDesc;
 import org.apache.servicemix.jbi.deployer.descriptor.SharedLibraryDesc;
 import org.apache.servicemix.jbi.deployer.descriptor.Target;
+import org.apache.servicemix.jbi.deployer.utils.OsgiStringUtils;
 import org.apache.servicemix.jbi.runtime.ComponentWrapper;
 import org.apache.servicemix.jbi.runtime.Environment;
 import org.apache.servicemix.nmr.api.event.ListenerRegistry;
@@ -67,7 +69,6 @@ import org.osgi.framework.BundleEvent;
 import org.osgi.service.prefs.Preferences;
 import org.osgi.service.prefs.PreferencesService;
 import org.osgi.util.tracker.ServiceTracker;
-import org.springframework.osgi.util.OsgiStringUtils;
 
 /**
  * Deployer for JBI artifacts
@@ -102,8 +103,6 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
 
     private File jbiRootDir;
 
-    private PreferencesService preferencesService;
-
     private boolean autoStart = true;
 
     private ServiceTracker deployedComponentsTracker;
@@ -114,17 +113,14 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
     
     private int shutdownTimeout;
 
-    // Helper beans
-    private ManagementStrategy managementStrategy;
     private Environment environment;
 
     private ListenerRegistry listenerRegistry;
     
-    private MBeanServer mbeanServer;
+    private Storage storage;
 
     public Deployer() throws JBIException {
-        // TODO: control that using properties
-        jbiRootDir = new File(System.getProperty("karaf.base"), "data/jbi");
+    	jbiRootDir = new File(System.getProperty("karaf.base"), System.getProperty("jbi.cache", "data/jbi/"));
         jbiRootDir.mkdirs();
         // Create listener registry
         listenerRegistry = new ListenerRegistryImpl();
@@ -139,14 +135,6 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
         this.bundleContext = bundleContext;
     }
 
-    public PreferencesService getPreferencesService() {
-        return preferencesService;
-    }
-
-    public void setPreferencesService(PreferencesService preferencesService) {
-        this.preferencesService = preferencesService;
-    }
-
     public boolean isAutoStart() {
         return autoStart;
     }
@@ -163,22 +151,6 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
         return endpointListener;
     }
 
-    public ManagementStrategy getManagementStrategy() {
-        return managementStrategy;
-    }
-
-    public void setManagementStrategy(ManagementStrategy managementStrategy) {
-        this.managementStrategy = managementStrategy;
-    }
-    
-    public MBeanServer getMbeanServer() {
-        return mbeanServer;
-    }
-
-    public void setMbeanServer(MBeanServer mbeanServer) {
-        this.mbeanServer = mbeanServer;
-    }
-
     public void setEnvironment(Environment environment) {
         this.environment = environment;
     }
@@ -228,6 +200,14 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
     }
 
     public void init() throws Exception {
+        // Init storage
+        SimpleStorage s = new SimpleStorage(bundleContext.getDataFile("storage.properties"));
+        try {
+            s.load();
+        } catch (IOException e) {
+            LOGGER.warn("Error loading JBI artifacts state", e);
+        }
+        this.storage = s;
         // Track bundles
         bundleContext.addBundleListener(this);
         for (Bundle bundle : bundleContext.getBundles()) {
@@ -251,8 +231,10 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
         deployedComponentsTracker.open();
         // Track deployed service assemblies
         deployedAssembliesTracker = new ServiceTracker(bundleContext, DeployedAssembly.class.getName(), null) {
+        	
             public Object addingService(ServiceReference serviceReference) {
-                Object o = super.addingService(serviceReference);
+            	Object o = super.addingService(serviceReference);
+                
                 registerDeployedServiceAssembly(serviceReference, (DeployedAssembly) o);
                 return o;
             }
@@ -411,8 +393,8 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
         props.put(NAME, sharedLibraryDesc.getIdentification().getName());
         LOGGER.debug("Registering JBI Shared Library");
         registerService(bundle, SharedLibrary.class.getName(), sl, props);
-        if (!getManagementStrategy().isManaged(sl, null)) {
-        	getManagementStrategy().manageObject(sl);
+        if (!getEnvironment().isManaged(sl)) {
+        	getEnvironment().manageObject(sl);
         }
         // Check pending bundles
         checkPendingInstallers();
@@ -421,8 +403,7 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
 
     public ComponentImpl registerComponent(Bundle bundle, ComponentDesc componentDesc, javax.jbi.component.Component innerComponent, SharedLibrary[] sharedLibraries) throws Exception {
         String name = componentDesc.getIdentification().getName();
-        Preferences prefs = preferencesService.getUserPreferences(name);
-        ComponentImpl component = new ComponentImpl(bundle, componentDesc, innerComponent, prefs, autoStart, sharedLibraries);
+        ComponentImpl component = new ComponentImpl(bundle, componentDesc, innerComponent, storage.getStorage(name), autoStart, sharedLibraries);
         component.setListenerRegistry(listenerRegistry);
         // populate props from the component meta-data
         Dictionary<String, String> props = new Hashtable<String, String>();
@@ -440,16 +421,17 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
         if (!wrappedComponents.containsKey(name)) {
             registerService(bundle, javax.jbi.component.Component.class.getName(), innerComponent, props);
         }
-        if (!getManagementStrategy().isManaged(component, null)) {
-        	getManagementStrategy().manageObject(component);
+        if (!getEnvironment().isManaged(component)) {
+        	getEnvironment().manageObject(component);
         }
         return component;
     }
 
     public ServiceAssemblyImpl registerServiceAssembly(Bundle bundle, ServiceAssemblyDesc serviceAssemblyDesc, List<ServiceUnitImpl> sus) throws Exception {
         // Now create the SA and initialize it
-        Preferences prefs = preferencesService.getUserPreferences(serviceAssemblyDesc.getIdentification().getName());
-        ServiceAssemblyImpl sa = new ServiceAssemblyImpl(bundle, serviceAssemblyDesc, sus, prefs, endpointListener, autoStart);
+        ServiceAssemblyImpl sa = new ServiceAssemblyImpl(bundle, serviceAssemblyDesc, sus, 
+                                                         storage.getStorage(serviceAssemblyDesc.getIdentification().getName()),
+                                                         endpointListener, autoStart);
         sa.setShutdownTimeout(shutdownTimeout);
         sa.setListenerRegistry(listenerRegistry);
         sa.init();
@@ -460,9 +442,9 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
         // register the service assembly in the OSGi registry
         LOGGER.debug("Registering JBI service assembly");
         registerService(bundle, ServiceAssembly.class.getName(), sa, props);
-        if (!getManagementStrategy().isManaged(sa, null)) {
+        if (!getEnvironment().isManaged(sa)) {
         	//check if this SA is managed, this is the case that restart SA bundle
-        	getManagementStrategy().manageObject(sa);
+        	getEnvironment().manageObject(sa);
         }
         return sa;
     }
@@ -505,7 +487,7 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
             }
             components.remove(component.getName());
             try {
-				getManagementStrategy().unmanageObject(component);
+				getEnvironment().unmanageObject(component);
 			} catch (Exception e) {
 				LOGGER.error("Error unmanage component: " + component.getName(), e);
 			}
@@ -518,7 +500,7 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
             pendingAssemblies.remove(assembly);
             unregisterServices(assembly.getBundle());
             try {
-				getManagementStrategy().unmanageObject(assembly);
+				getEnvironment().unmanageObject(assembly);
 			} catch (Exception e) {
 				LOGGER.error("Error unmanage service assembly: " + assembly.getName(), e);
 			}
@@ -533,7 +515,7 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
             // TODO: shutdown all components
             sharedLibraries.remove(library.getName());
             try {
-				getManagementStrategy().unmanageObject(library);
+				getEnvironment().unmanageObject(library);
 			} catch (Exception e) {
 				LOGGER.error("Error unmanage sharedlibrary: " + library.getName(), e);
 			}
@@ -553,6 +535,11 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
         return null;
     }
 
+    public Storage getStorage(String name) {
+        return storage.getStorage(name);
+    }
+
+
     //===============================================================================
     //
     //   Pending artifacts support
@@ -627,7 +614,7 @@ public class Deployer implements SynchronousBundleListener, LifeCycleListener {
         // propagate lifecycle event to management strategy
         // 
         try {
-            getManagementStrategy().notify(event);
+            getEnvironment().notify(event);
         } catch (Exception e) {
             // ignore
         }
